==> jc-1.4.0.tar.gz: javax/print/StreamPrintService.h <==
// public abstract class javax.print.StreamPrintService

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8f48a8aba082466 javax_print_StreamPrintService

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_StreamPrintService_H_
#define _JC_javax_print_StreamPrintService_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_StreamPrintService$sub_refs	_jc_javax_print_StreamPrintService$sub_refs;
typedef struct _jc_javax_print_StreamPrintService$sub_nonrefs	_jc_javax_print_StreamPrintService$sub_nonrefs;
typedef struct _jc_javax_print_StreamPrintService$refs	_jc_javax_print_StreamPrintService$refs;
typedef struct _jc_javax_print_StreamPrintService$nonrefs	_jc_javax_print_StreamPrintService$nonrefs;
typedef struct _jc_javax_print_StreamPrintService$object	_jc_javax_print_StreamPrintService$object;

typedef const struct _jc_javax_print_StreamPrintService$vmethods	_jc_javax_print_StreamPrintService$vmethods;
typedef const struct _jc_javax_print_StreamPrintService$vtable	_jc_javax_print_StreamPrintService$vtable;
typedef const struct _jc_javax_print_StreamPrintService$vtype	_jc_javax_print_StreamPrintService$vtype;

// Constructors
extern void _jc_javax_print_StreamPrintService$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_javax_print_StreamPrintService$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_javax_print_StreamPrintService$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_StreamPrintService$method$getOutputFormat$6a03a5aca3371fa6(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
extern struct _jc_java_io_OutputStream$object *_jc_javax_print_StreamPrintService$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
extern jboolean _jc_javax_print_StreamPrintService$method$isDisposed$26a0e0f6ae6221d1(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_StreamPrintService$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_javax_print_StreamPrintService$method_info$getOutputFormat$6a03a5aca3371fa6;
extern _jc_method _jc_javax_print_StreamPrintService$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_javax_print_StreamPrintService$method_info$isDisposed$26a0e0f6ae6221d1;

// Virtual methods structure
struct _jc_javax_print_StreamPrintService$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
	struct _jc_java_lang_String$object	*(*getOutputFormat$6a03a5aca3371fa6)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
	jboolean	(*isDisposed$26a0e0f6ae6221d1)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *);
};

// Vtable
struct _jc_javax_print_StreamPrintService$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_StreamPrintService$vmethods	javax_print_StreamPrintService;
};

// Vtype
struct _jc_javax_print_StreamPrintService$vtype {
	_jc_type			type;
	_jc_javax_print_StreamPrintService$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_StreamPrintService$sub_refs {
	struct _jc_java_io_OutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_javax_print_StreamPrintService$refs {
    _jc_javax_print_StreamPrintService$sub_refs	javax_print_StreamPrintService;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_StreamPrintService$sub_nonrefs {
	jboolean	disposed;
};

// Non-reference instance fields (object)
struct _jc_javax_print_StreamPrintService$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_StreamPrintService$sub_nonrefs	javax_print_StreamPrintService;
};

// Object instance structure
struct _jc_javax_print_StreamPrintService$object {
	_jc_javax_print_StreamPrintService$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_StreamPrintService$vtype	*vtype;
	_jc_javax_print_StreamPrintService$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_StreamPrintService$vtype _jc_javax_print_StreamPrintService$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_StreamPrintService, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_StreamPrintService$class_object;

#endif	/* _JC_javax_print_StreamPrintService_H_ */

==> jc-1.4.6.tar.gz: javax/print/StreamPrintService.h <==
// public abstract class javax.print.StreamPrintService

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8f48a8aba082466 javax_print_StreamPrintService

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_StreamPrintService_H_
#define _JC_javax_print_StreamPrintService_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_StreamPrintService$sub_refs	_jc_javax_print_StreamPrintService$sub_refs;
typedef struct _jc_javax_print_StreamPrintService$sub_nonrefs	_jc_javax_print_StreamPrintService$sub_nonrefs;
typedef struct _jc_javax_print_StreamPrintService$refs	_jc_javax_print_StreamPrintService$refs;
typedef struct _jc_javax_print_StreamPrintService$nonrefs	_jc_javax_print_StreamPrintService$nonrefs;
typedef struct _jc_javax_print_StreamPrintService$object	_jc_javax_print_StreamPrintService$object;

typedef const struct _jc_javax_print_StreamPrintService$vmethods	_jc_javax_print_StreamPrintService$vmethods;
typedef const struct _jc_javax_print_StreamPrintService$vtable	_jc_javax_print_StreamPrintService$vtable;
typedef const struct _jc_javax_print_StreamPrintService$vtype	_jc_javax_print_StreamPrintService$vtype;

// Constructors
extern void _jc_javax_print_StreamPrintService$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_javax_print_StreamPrintService$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_print_StreamPrintService$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_StreamPrintService$method$getOutputFormat$6a03a5aca3371fa6(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_javax_print_StreamPrintService$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_print_StreamPrintService$method$isDisposed$26a0e0f6ae6221d1(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_StreamPrintService$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_javax_print_StreamPrintService$method_info$getOutputFormat$6a03a5aca3371fa6;
extern _jc_method _jc_javax_print_StreamPrintService$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_javax_print_StreamPrintService$method_info$isDisposed$26a0e0f6ae6221d1;

// Virtual methods structure
struct _jc_javax_print_StreamPrintService$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getOutputFormat$6a03a5aca3371fa6)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
	jboolean	(*isDisposed$26a0e0f6ae6221d1)(_jc_env *, struct _jc_javax_print_StreamPrintService$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_StreamPrintService$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_StreamPrintService$vmethods	javax_print_StreamPrintService;
};

// Vtype
struct _jc_javax_print_StreamPrintService$vtype {
	_jc_type			type;
	_jc_javax_print_StreamPrintService$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_StreamPrintService$sub_refs {
	struct _jc_java_io_OutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_javax_print_StreamPrintService$refs {
    _jc_javax_print_StreamPrintService$sub_refs	javax_print_StreamPrintService;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_StreamPrintService$sub_nonrefs {
	jboolean	disposed;
};

// Non-reference instance fields (object)
struct _jc_javax_print_StreamPrintService$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_StreamPrintService$sub_nonrefs	javax_print_StreamPrintService;
};

// Object instance structure
struct _jc_javax_print_StreamPrintService$object {
	_jc_javax_print_StreamPrintService$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_StreamPrintService$vtype	*vtype;
	_jc_javax_print_StreamPrintService$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_StreamPrintService$vtype _jc_javax_print_StreamPrintService$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_StreamPrintService, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_StreamPrintService$class_object;

#endif	/* _JC_javax_print_StreamPrintService_H_ */
